@@ -1,7 +1,12 @@
 import json
 import re
+import uuid
 
 import boto3
+from botocore.exceptions import ClientError
+from cloudlift.exceptions import UnrecoverableException
+from cloudlift.config import get_client_for
+
 from awacs.aws import PolicyDocument, Statement, Allow, Principal
 from awacs.sts import AssumeRole
 from cfn_flip import to_yaml
@@ -54,6 +59,9 @@ class ServiceTemplateGenerator(TemplateGenerator):
         self.environment_stack = environment_stack
         self.current_version = ServiceInformationFetcher(
             self.application_name, self.env).get_current_version()
+        self.bucket_name = 'cloudlift-service-template'
+        self.environment = service_configuration.environment
+        self.client = get_client_for('s3', self.environment)
 
     def _derive_configuration(self, service_configuration):
         self.application_name = service_configuration.service_name
@@ -65,7 +73,25 @@ class ServiceTemplateGenerator(TemplateGenerator):
         self._fetch_current_desired_count()
         self._add_ecs_service_iam_role()
         self._add_cluster_services()
-        return to_yaml(self.template.to_json())
+
+        key = uuid.uuid4().hex + '.yml'
+        if len(to_yaml(self.template.to_json())) > 51000:
+            try:
+                self.client.put_object(
+                    Body=to_yaml(self.template.to_json()),
+                    Bucket=self.bucket_name,
+                    Key=key,
+                )
+                template_url = f'https://{self.bucket_name}.s3.amazonaws.com/{key}'
+                return template_url, 'TemplateURL', key
+            except ClientError as boto_client_error:
+                error_code = boto_client_error.response['Error']['Code']
+                if error_code == 'AccessDenied':
+                    raise UnrecoverableException(f'Unable to store cloudlift service template in S3 bucket at {self.bucket_name}')
+                else:
+                    raise boto_client_error
+        else:
+            return to_yaml(self.template.to_json()), 'TemplateBody', ''
 
     def _add_cluster_services(self):
         for ecs_service_name, config in self.configuration['services'].items():
